@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importalarmjobinterfacetest.h"
@@ -47,11 +34,11 @@ void ImportAlarmJobInterfaceTest::importAlarmConfig()
     QFETCH(QString, testPath);
     QFETCH(Utils::StoredTypes, options);
     const QString fullTestPath = zipFilePath + testPath;
-    TestImportFile *file = new TestImportFile(fullTestPath, this);
+    auto *file = new TestImportFile(fullTestPath, this);
     file->setPathConfig(fullTestPath);
     file->setExtractPath(QDir::tempPath() + testPath);
     file->setExcludePath(Utils::alarmPath());
-    ImportAlarmJobInterfaceTestImpl *impl = new ImportAlarmJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
+    auto *impl = new ImportAlarmJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
     impl->setPathConfig(file->pathConfig());
     impl->setExtractPath(file->extractPath());
     impl->setTempDirName(file->extractPath());
