@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importcalendarjobinterface.h"
@@ -103,7 +90,7 @@ void ImportCalendarJobInterface::restoreConfig()
     const QString oldKorganizerPrintrrcStr(QStringLiteral("korganizer_printing.rc"));
     const KArchiveEntry *oldKorganizerPrinterEntry = mArchiveDirectory->entry(Utils::configsPath() + oldKorganizerPrintrrcStr);
     if (oldKorganizerPrinterEntry && oldKorganizerPrinterEntry->isFile()) {
-        const KArchiveFile *korganizerFile = static_cast<const KArchiveFile *>(oldKorganizerPrinterEntry);
+        const auto *korganizerFile = static_cast<const KArchiveFile *>(oldKorganizerPrinterEntry);
         const QString oldKorganizerPrintrrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + korganizerPrinterrcStr;
         if (QFileInfo::exists(oldKorganizerPrintrrc)) {
             if (overwriteConfigMessageBox(oldKorganizerPrintrrc)) {
@@ -115,7 +102,7 @@ void ImportCalendarJobInterface::restoreConfig()
     } else {
         const KArchiveEntry *korganizerPrinterEntry = mArchiveDirectory->entry(Utils::configsPath() + korganizerPrinterrcStr);
         if (korganizerPrinterEntry && korganizerPrinterEntry->isFile()) {
-            const KArchiveFile *korganizerFile = static_cast<const KArchiveFile *>(korganizerPrinterEntry);
+            const auto *korganizerFile = static_cast<const KArchiveFile *>(korganizerPrinterEntry);
             const QString korganizerPrinterrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + korganizerPrinterrcStr;
             if (QFileInfo::exists(korganizerPrinterrc)) {
                 if (overwriteConfigMessageBox(korganizerPrinterrcStr)) {
@@ -130,7 +117,7 @@ void ImportCalendarJobInterface::restoreConfig()
     const QString korganizerStr(QStringLiteral("korganizerrc"));
     const KArchiveEntry *korganizerrcentry = mArchiveDirectory->entry(Utils::configsPath() + korganizerStr);
     if (korganizerrcentry && korganizerrcentry->isFile()) {
-        const KArchiveFile *korganizerrcFile = static_cast<const KArchiveFile *>(korganizerrcentry);
+        const auto *korganizerrcFile = static_cast<const KArchiveFile *>(korganizerrcentry);
         const QString korganizerrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + korganizerStr;
         if (QFileInfo::exists(korganizerrc)) {
             if (overwriteConfigMessageBox(korganizerStr)) {
@@ -144,7 +131,7 @@ void ImportCalendarJobInterface::restoreConfig()
     const QString eventviewStr(QStringLiteral("eventviewsrc"));
     const KArchiveEntry *eventviewentry = mArchiveDirectory->entry(Utils::configsPath() + eventviewStr);
     if (eventviewentry && eventviewentry->isFile()) {
-        const KArchiveFile *eventviewrcFile = static_cast<const KArchiveFile *>(eventviewentry);
+        const auto *eventviewrcFile = static_cast<const KArchiveFile *>(eventviewentry);
         const QString eventviewrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + eventviewStr;
         if (QFileInfo::exists(eventviewrc)) {
             if (overwriteConfigMessageBox(eventviewStr)) {
@@ -158,7 +145,7 @@ void ImportCalendarJobInterface::restoreConfig()
     const QString korgacStr(QStringLiteral("korgacrc"));
     const KArchiveEntry *korgacrcentry = mArchiveDirectory->entry(Utils::configsPath() + korgacStr);
     if (korgacrcentry && korgacrcentry->isFile()) {
-        const KArchiveFile *korgacrcFile = static_cast<const KArchiveFile *>(korgacrcentry);
+        const auto *korgacrcFile = static_cast<const KArchiveFile *>(korgacrcentry);
         const QString korgacrc = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + korgacStr;
         if (QFileInfo::exists(korgacrc)) {
             if (overwriteConfigMessageBox(korgacStr)) {
@@ -172,7 +159,7 @@ void ImportCalendarJobInterface::restoreConfig()
     const QString freebusyStr(QStringLiteral("freebusyurls"));
     const KArchiveEntry *freebusyentry = mArchiveDirectory->entry(Utils::dataPath() + QLatin1String("korganizer/") + freebusyStr);
     if (freebusyentry && freebusyentry->isFile()) {
-        const KArchiveFile *freebusyrcFile = static_cast<const KArchiveFile *>(freebusyentry);
+        const auto *freebusyrcFile = static_cast<const KArchiveFile *>(freebusyentry);
 
         const QString freebusypath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/korganizer/") + freebusyStr;
         if (QFileInfo::exists(freebusypath)) {
@@ -189,7 +176,7 @@ void ImportCalendarJobInterface::restoreConfig()
     if (templateEntry && templateEntry->isDirectory()) {
         //TODO 4.12 verify if template already exists.
         const QString templatePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("korganizer/templates/");
-        const KArchiveDirectory *templateDir = static_cast<const KArchiveDirectory *>(templateEntry);
+        const auto *templateDir = static_cast<const KArchiveDirectory *>(templateEntry);
         if (!templateDir->copyTo(templatePath)) {
             qCDebug(PIMDATAEXPORTERCORE_LOG) << "template cannot copy to " << templatePath;
         }
@@ -198,7 +185,7 @@ void ImportCalendarJobInterface::restoreConfig()
     const KArchiveEntry *designerEntry = mArchiveDirectory->entry(Utils::dataPath() + QStringLiteral("korganizer/designer/"));
     if (designerEntry && designerEntry->isDirectory()) {
         const QString templatePath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("korganizer/designer/");
-        const KArchiveDirectory *templateDir = static_cast<const KArchiveDirectory *>(designerEntry);
+        const auto *templateDir = static_cast<const KArchiveDirectory *>(designerEntry);
         if (!templateDir->copyTo(templatePath)) {
             qCDebug(PIMDATAEXPORTERCORE_LOG) << "template cannot copy to " << templatePath;
         }
@@ -266,7 +253,7 @@ void ImportCalendarJobInterface::restoreResources()
             if (value.akonadiConfigFile.contains(QLatin1String("akonadi_icaldir_resource_"))) {
                 const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(value.akonadiConfigFile);
                 if (fileResouceEntry && fileResouceEntry->isFile()) {
-                    const KArchiveFile *file = static_cast<const KArchiveFile *>(fileResouceEntry);
+                    const auto *file = static_cast<const KArchiveFile *>(fileResouceEntry);
                     copyArchiveFileTo(file, copyToDirName);
                     QString resourceName(file->name());
 
@@ -283,7 +270,7 @@ void ImportCalendarJobInterface::restoreResources()
                     const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
                     bool isDirResource = value.akonadiConfigFile.contains(QLatin1String("akonadi_icaldir_resource_"));
                     if (dataResouceEntry->isFile()) {
-                        const KArchiveFile *file = static_cast<const KArchiveFile *>(dataResouceEntry);
+                        const auto *file = static_cast<const KArchiveFile *>(dataResouceEntry);
                         //TODO  adapt directory name too
                         extractZipFile(file, copyToDirName, newUrlInfo.path(), value.akonadiConfigFile.contains(QLatin1String("akonadi_icaldir_resource_")));
                     }
@@ -293,7 +280,7 @@ void ImportCalendarJobInterface::restoreResources()
                     if (!agentConfigFile.isEmpty()) {
                         const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
                         if (akonadiAgentConfigEntry->isFile()) {
-                            const KArchiveFile *file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
+                            const auto *file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
                             copyArchiveFileTo(file, copyToDirName);
                             resourceName = file->name();
                             filename = Utils::akonadiAgentName(copyToDirName + QLatin1Char('/') + resourceName);
